//
//  MNUMETableViewController.h
//  UMEKit
//
//  Created by Masatoshi Nishikata on 10/12/12.
//
//

#import <UMEKit/UMEKit.h>

typedef NSInteger UITableViewStyle;

#define UITableViewCellStyleDefault 0
#define UITableViewCellAccessoryNone 0

@class UIColor;


@interface MNUMEScrollView : NSScrollView

@end

#pragma mark - UITableViewCell

@interface UITableViewCell : NSTableCellView
- (id)initWithStyle:(NSInteger)style reuseIdentifier:(NSString *)reuseIdentifier;
-(void)setUserInteractionEnabled:(BOOL)flag;

@property (nonatomic, readonly) NSView* contentView;
@property (nonatomic, readwrite) NSInteger accessoryType;
@property (nonatomic, assign) id backgroundColor;

@end

#pragma mark - UITableView


@interface UITableView : NSTableView
- (void)reloadRowsAtIndexPaths:(NSArray *)indexPaths withRowAnimation:(NSInteger)animation;
- (void)selectRowAtIndexPath:(NSIndexPath *)indexPath animated:(BOOL)animated scrollPosition:(NSInteger)scrollPosition;
- (void)deselectRowAtIndexPath:(NSIndexPath *)indexPath animated:(BOOL)animated;
- (NSIndexPath *)indexPathForSelectedRow;
- (void)deleteRowsAtIndexPaths:(NSArray *)indexPaths withRowAnimation:(NSInteger)animation;
- (void)insertRowsAtIndexPaths:(NSArray *)indexPaths withRowAnimation:(NSInteger)animation;

@end

#pragma mark - MNUMETableViewController

@class UMEToolbar;
@interface MNUMETableViewController : UMEViewController <NSTableViewDataSource, NSTableViewDelegate>
{
	UITableView* __weak tableView_;
	
@protected
	MNUMEScrollView * tableContainer_;
	UMEToolbar* toolbar_;

}

@property(nonatomic, readonly) UITableView *tableView;

- (id)initWithStyle:(UITableViewStyle)style;
- (NSView *)tableView:(NSTableView *)tableView viewForTableColumn:(NSTableColumn *)tableColumn row:(NSInteger)row;

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section;
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath;
- (BOOL)tableView:(NSTableView *)aTableView shouldSelectRow:(NSInteger)rowIndex;
- (NSIndexPath *)tableView:(UITableView *)tableView willSelectRowAtIndexPath:(NSIndexPath *)indexPath;

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath;
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath;

@end

#pragma mark - NSIndexPath

@interface NSIndexPath (MNUMETableViewController)
+ (NSIndexPath *)indexPathForRow:(NSInteger)row inSection:(NSInteger)section;
@property(nonatomic, readonly) NSInteger section;
@property(nonatomic, readonly) NSInteger row;


@end

